@@ -454,9 +454,15 @@ public abstract class AbstractPinTanPassport extends AbstractHBCIPassport
         final String prefix = "TAN2Step" + version;
         k.rawSet(prefix,"requested"); // forcieren, dass das Segment mit gesendet wird - auch wenn es eigentlich optional ist
         k.rawSet(prefix + ".process",tp.getCode());
-        
-        final String segcode = sca.getTanReference();
-        HBCIUtils.log("creating HKTAN for SCA [process : " + tp + "], order code: " + segcode + "]",HBCIUtils.LOG_DEBUG);
+
+
+        String segcode = sca.getTanReference();
+        if (Feature.PINTAN_SEGCODE_STRICT.isEnabled())
+        {
+          if (tp == KnownTANProcess.PROCESS2_STEP2)
+            segcode = "";
+        }
+        HBCIUtils.log("creating HKTAN for SCA [process : " + tp + ", order code: " + segcode + "]",HBCIUtils.LOG_DEBUG);
         
         k.rawSet(prefix + ".ordersegcode",segcode);
         k.rawSet(prefix + ".OrderAccount.bic","");
@@ -467,7 +473,7 @@ public abstract class AbstractPinTanPassport extends AbstractHBCIPassport
         k.rawSet(prefix + ".OrderAccount.KIK.country","");
         k.rawSet(prefix + ".orderhash",(variant == Variant.V2) ? "" : ("B00000000"));
         k.rawSet(prefix + ".orderref",(step == 2) ? (String) this.getPersistentData(KEY_PD_ORDERREF) : "");
-        k.rawSet(prefix + ".notlasttan","N");
+        k.rawSet(prefix + ".notlasttan",(tp == KnownTANProcess.PROCESS1 || tp == KnownTANProcess.PROCESS2_STEP2) ? "N" : ""); // Darf nur bei TAN-Prozess 1 und 2 belegt sein
         k.rawSet(prefix + ".challengeklass",(variant == Variant.V2) ? "" : "99");
         k.rawSet(prefix + ".tanmedia",sca.getTanMedia());
     }
